# ConfiGator

![Mr.ConfiGator himself](img/icon.png)

[![Lint and Test](https://github.com/cmpsc-481-s22-m1/ConfiGator/actions/workflows/main.yml/badge.svg?branch=release%2F0.1.0)](https://github.com/cmpsc-481-s22-m1/ConfiGator/actions/workflows/main.yml)

A configuration file generator meant to be used with [GatorGradle](https://github.com/GatorEducator/gatorgradle).

## Overview

ConfiGator is a tool to be used in hand with GatorGradle to generate configuration
files for assignments that require GatorGradle. ConfiGator uses
[Poetry](https://python-poetry.org/) for package and dependency management.

## Usage

### Installing ConfiGator

Command to install ConfiGator

```bash
pipx install configator
```

### Command to Change Specific Configurations

The command below will show a list of every available command to change
specific configurations in `config/gatorgrader.yml` or `build.gradle`.

```bash
configator --help
```

### If you need Assistance

Create an issue or a discussion post for assistance if you encounter any issues
with ConfiGator.

### Contributors

- [@connellyw](https://github.com/connellyw)
- [@donizk](https://github.com/donizk)
- [@Kevin487](https://github.com/Kevin487)
- [@Peter-Snipes](https://github.com/Peter-Snipes)
- [@kailaniwoodard](https://github.com/kailaniwoodard)
- [@TheShiny1](https://github.com/TheShiny1)
- [@mariakimheinert](https://github.com/mariakimheinert)
- [@Michionlion](https://github.com/Michionlion)
